==> haskell-blaze-builder-0.4.0.1-2-armv7h.pkg.tar.xz: usr/share/haskell/haskell-blaze-builder/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: blaze-builder
version: 0.4.0.1
id: blaze-builder-0.4.0.1-adef087994cafeb1970772b79d5f710a
key: blaze_7D6Na2HAomq3FxaKuJX0DE
license: BSD3
copyright: (c) 2010-2014 Simon Meier
           (c) 2010 Jasper Van der Jeugt
           (c) 2013-2015 Leon P Smith
maintainer: Leon Smith <leon@melding-monads.com>
stability: Experimental
homepage: http://github.com/lpsmith/blaze-builder
synopsis: Efficient buffered output.
description:
    This library provides an implementation of the older
    blaze-builder interface in terms of the new builder that
    shipped with bytestring-0.10.4.0
    .
    This implementation is mostly intended as a bridge to the
    new builder,  so that code that uses the old interface
    can interoperate with code that uses the new
    implementation.   Note that no attempt has been made
    to preserve the old internal modules,  so code that
    has these dependencies cannot use this interface.
    .
    New code should,  for the most part,  use the new
    interface.   However, this module does implement
    a chunked HTTP encoding,  which is not otherwise
    implemented (yet?) with the new builder.
category: Data
author: Jasper Van der Jeugt, Simon Meier, Leon P Smith
exposed: True
exposed-modules:
    Blaze.ByteString.Builder Blaze.ByteString.Builder.Int
    Blaze.ByteString.Builder.Word Blaze.ByteString.Builder.ByteString
    Blaze.ByteString.Builder.Char.Utf8 Blaze.ByteString.Builder.Char8
    Blaze.ByteString.Builder.Html.Utf8 Blaze.ByteString.Builder.HTTP
    Blaze.ByteString.Builder.Compat.Write
    Blaze.ByteString.Builder.Internal.Write
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/blaze-builder-0.4.0.1
library-dirs: /usr/lib/ghc-7.10.3/site-local/blaze-builder-0.4.0.1
data-dir: /usr/share/arm-linux-ghc-7.10.3/blaze-builder-0.4.0.1
hs-libraries: HSblaze-builder-0.4.0.1-7D6Na2HAomq3FxaKuJX0DE
depends:
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
    deepseq-1.4.1.1-3975618f889b45239daa47b7443eaeee
    text-1.2.1.3-6c3c87c392cdf2c29fca1c10bbf7250b
haddock-interfaces: /usr/share/doc/haskell-blaze-builder/html/blaze-builder.haddock
haddock-html: /usr/share/doc/haskell-blaze-builder/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"

==> haskell-blaze-builder-0.4.0.1-3-armv7h.pkg.tar.xz: usr/share/haskell/haskell-blaze-builder/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: blaze-builder
version: 0.4.0.1
id: blaze-builder-0.4.0.1-3daa45cd3be9618b289586d273c59e36
key: blaze_GoSGMrJXTmeEBoF3sgxwrM
license: BSD3
copyright: (c) 2010-2014 Simon Meier
           (c) 2010 Jasper Van der Jeugt
           (c) 2013-2015 Leon P Smith
maintainer: Leon Smith <leon@melding-monads.com>
stability: Experimental
homepage: http://github.com/lpsmith/blaze-builder
synopsis: Efficient buffered output.
description:
    This library provides an implementation of the older
    blaze-builder interface in terms of the new builder that
    shipped with bytestring-0.10.4.0
    .
    This implementation is mostly intended as a bridge to the
    new builder,  so that code that uses the old interface
    can interoperate with code that uses the new
    implementation.   Note that no attempt has been made
    to preserve the old internal modules,  so code that
    has these dependencies cannot use this interface.
    .
    New code should,  for the most part,  use the new
    interface.   However, this module does implement
    a chunked HTTP encoding,  which is not otherwise
    implemented (yet?) with the new builder.
category: Data
author: Jasper Van der Jeugt, Simon Meier, Leon P Smith
exposed: True
exposed-modules:
    Blaze.ByteString.Builder Blaze.ByteString.Builder.Int
    Blaze.ByteString.Builder.Word Blaze.ByteString.Builder.ByteString
    Blaze.ByteString.Builder.Char.Utf8 Blaze.ByteString.Builder.Char8
    Blaze.ByteString.Builder.Html.Utf8 Blaze.ByteString.Builder.HTTP
    Blaze.ByteString.Builder.Compat.Write
    Blaze.ByteString.Builder.Internal.Write
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/blaze-builder-0.4.0.1
library-dirs: /usr/lib/ghc-7.10.3/site-local/blaze-builder-0.4.0.1
data-dir: /usr/share/arm-linux-ghc-7.10.3/blaze-builder-0.4.0.1
hs-libraries: HSblaze-builder-0.4.0.1-GoSGMrJXTmeEBoF3sgxwrM
depends:
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
    deepseq-1.4.1.1-3975618f889b45239daa47b7443eaeee
    text-1.2.2.0-2f82ea4adfdd656d9a8840ad2ee17cc0
haddock-interfaces: /usr/share/doc/haskell-blaze-builder/html/blaze-builder.haddock
haddock-html: /usr/share/doc/haskell-blaze-builder/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
